#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enummapset
version:              0.7.3.0
visibility:           public
id:                   enummapset-0.7.3.0-GTrCMZkhGZx30bCzvngb4j
key:                  enummapset-0.7.3.0-GTrCMZkhGZx30bCzvngb4j
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Michal Terepeta and others
homepage:             https://github.com/Mikolaj/enummapset
synopsis:             IntMap and IntSet with Enum keys/elements.
description:
    This package contains simple wrappers around '\''Data.IntMap'\'' and
    '\''Data.IntSet'\'' with '\''Enum'\'' keys and elements respectively.
    Especially useful for '\''Int'\''s wrapped with `newtype`.

category:             Data Structures
abi:                  0e18a815e974fd843afce74b7d4d1bd8
exposed:              True
exposed-modules:
    Data.EnumMap Data.EnumMap.Lazy Data.EnumMap.Strict Data.EnumSet

hidden-modules:       Data.EnumMap.Base
import-dirs:          /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/enummapset-0.7.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enummapset
hs-libraries:         HSenummapset-0.7.3.0-GTrCMZkhGZx30bCzvngb4j
depends:
    aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1

haddock-interfaces:   /usr/share/doc/haskell-enummapset/html/enummapset.haddock
haddock-html:         /usr/share/doc/haskell-enummapset/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

